kubernetes

package
v0.0.0-...-ca42ad6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2023 License: MIT Imports: 42 Imported by: 0

Documentation

Index

Constants

const (
	// SuccessSynced is used as part of the Event 'reason' when a DevWorkspace is synced
	SuccessSynced = "Synced"
	// ErrResourceExists is used as part of the Event 'reason' when a DevWorkspace fails
	// to sync due to a Deployment of the same name already existing.
	ErrResourceExists = "ErrResourceExists"

	// MessageResourceExists is the message used for Events when a resource
	// fails to sync due to a Deployment already existing
	MessageResourceExists = "Resource %q already exists and is not managed by DevWorkspace"
	// MessageResourceSynced is the message used for an Event fired when a DevWorkspace
	// is synced successfully
	MessageResourceSynced = "DevWorkspace synced successfully"
)
const (
	KubeModeProd = "PRODUCTION"

	DevLocal  = "LOCAL"
	DevRemote = "REMOTE"
)

Variables

This section is empty.

Functions

func CreateDevWorkspace

func CreateDevWorkspace(workspaceId string, wsc schemas.Workspace) error

func QueryWorkspaceStatus

func QueryWorkspaceStatus(in *repo.Workspace) (out *repo.Workspace)

func ReopenWorkspace

func ReopenWorkspace(workspaceId uint) error

func StopWorkspace

func StopWorkspace(workspaceId uint) error

func TaskAndMilestoneIdByWorkspaceId

func TaskAndMilestoneIdByWorkspaceId(workspaceId uint) (taskId, milestoneId string)

func TaskIdByWorkspaceId

func TaskIdByWorkspaceId(workspaceId uint) string

Types

type Controller

type Controller struct {
	// contains filtered or unexported fields
}

Controller is the controller implementation for DevWorkspace resources

func NewController

NewController returns a new sample controller

func (*Controller) Run

func (c *Controller) Run(ctx context.Context, workers int) error

Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shut down the workqueue and wait for workers to finish processing their current work items.

Jump to