Documentation
¶
Index ¶
- Constants
- func CreateDevWorkspace(workspaceId string, wsc schemas.Workspace) error
- func QueryWorkspaceStatus(in *repo.Workspace) (out *repo.Workspace)
- func ReopenWorkspace(workspaceId uint) error
- func StopWorkspace(workspaceId uint) error
- func TaskAndMilestoneIdByWorkspaceId(workspaceId uint) (taskId, milestoneId string)
- func TaskIdByWorkspaceId(workspaceId uint) string
- type Controller
Constants ¶
const ( // SuccessSynced is used as part of the Event 'reason' when a DevWorkspace is synced SuccessSynced = "Synced" // ErrResourceExists is used as part of the Event 'reason' when a DevWorkspace fails // to sync due to a Deployment of the same name already existing. ErrResourceExists = "ErrResourceExists" // MessageResourceExists is the message used for Events when a resource // fails to sync due to a Deployment already existing MessageResourceExists = "Resource %q already exists and is not managed by DevWorkspace" // MessageResourceSynced is the message used for an Event fired when a DevWorkspace // is synced successfully MessageResourceSynced = "DevWorkspace synced successfully" )
const ( KubeModeProd = "PRODUCTION" DevLocal = "LOCAL" DevRemote = "REMOTE" )
Variables ¶
This section is empty.
Functions ¶
func ReopenWorkspace ¶
func StopWorkspace ¶
func TaskIdByWorkspaceId ¶
Types ¶
type Controller ¶
type Controller struct {
// contains filtered or unexported fields
}
Controller is the controller implementation for DevWorkspace resources
func NewController ¶
func NewController( ctx context.Context, kubeclientset kubernetes.Interface, ezclientset ezclientset.Interface, pvInformer coreinformers.PersistentVolumeInformer, pvcInformer coreinformers.PersistentVolumeClaimInformer, deploymentInformer appsinformers.DeploymentInformer, serviceInformer coreinformers.ServiceInformer, ingressInformer networkinginformers.IngressInformer, devworkspaceInformer ezinformers.DevWorkspaceInformer) *Controller
NewController returns a new sample controller
func (*Controller) Run ¶
func (c *Controller) Run(ctx context.Context, workers int) error
Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shut down the workqueue and wait for workers to finish processing their current work items.
Click to show internal directories.
Click to hide internal directories.